@@ -1,5 +1,7 @@
+# $Id: Loop.pm,v 1.5 2014-01-28 15:37:33 joern Exp $
+
 #-----------------------------------------------------------------------
-# Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+# Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
 # All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Event::RPC, which is free software; you can
@@ -8,9 +10,6 @@
 
 package Event::RPC::Loop;
 
-use strict;
-use utf8;
-
 sub new {
     my $class = shift;
     return bless {}, $class;
@@ -20,7 +19,7 @@ sub new {
 
 __END__
 
-=encoding utf8
+=encoding latin1
 
 =head1 NAME
 
@@ -155,11 +154,11 @@ no need to access it through Event::RPC::Loop.
 
 =head1 AUTHORS
 
-  Jörn Reder <joern AT zyn.de>
+  Jrn Reder <joern at zyn dot de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015 by Jörn Reder <joern AT zyn.de>.
+Copyright (C) 2002-2006 by Joern Reder, All Rights Reserved.
 
 This library is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
