@@ -1,4 +1,4 @@
-# $Id: Message.pm,v 1.7 2009-04-22 10:53:51 joern Exp $
+# $Id: Message.pm,v 1.9 2014-01-28 15:40:10 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2002-2006 Jrn Reder <joern AT zyn.de>.
@@ -15,6 +15,7 @@ use strict;
 use Storable;
 
 my $DEBUG = 0;
+my $MAX_PACKET_SIZE = 2*1024*1024*1024;
 
 sub get_sock                    { shift->{sock}                         }
 
@@ -26,12 +27,20 @@ sub set_buffer                  { shift->{buffer}               = $_[1] }
 sub set_length                  { shift->{length}               = $_[1] }
 sub set_written                 { shift->{written}              = $_[1] }
 
+sub get_max_packet_size {
+    return $MAX_PACKET_SIZE;
+}
+
+sub set_max_packet_size {
+    my $class = shift;
+    my ($value) = @_;
+    $MAX_PACKET_SIZE = $value;
+}
+
 sub new {
     my $class = shift;
     my ($sock) = @_;
 
-    $sock->blocking(1);
-
     my $self = bless {
         sock    => $sock,
         buffer  => undef,
@@ -44,7 +53,10 @@ sub new {
 
 sub read {
     my $self = shift;
+    my ($blocking) = @_;
 
+    $self->get_sock->blocking($blocking?1:0);
+    
     if ( not defined $self->{buffer} ) {
         my $length_packed;
         $DEBUG && print "DEBUG: going to read header...\n";
@@ -53,8 +65,8 @@ sub read {
         die "DISCONNECTED" if !(defined $rc) || $rc == 0;
         $self->{length} = unpack("N", $length_packed);
         $DEBUG && print "DEBUG: packet size=$self->{length}\n";
-        die "Incoming message too big"
-                if $self->{length} > 4194304;
+        die "Incoming message size exceeds limit of $MAX_PACKET_SIZE bytes"
+                if $self->{length} > $MAX_PACKET_SIZE;
     }
 
     my $buffer_length = length($self->{buffer}||'');
@@ -94,24 +106,38 @@ sub read_blocked {
     my $self = shift;
 
     my $rc;
-    $rc = $self->read while not defined $rc;
+    $rc = $self->read(1) while not defined $rc;
 
     return $rc;
 }
 
-sub write {
+sub set_data {
     my $self = shift;
     my ($data) = @_;
 
-    $DEBUG && print "DEBUG: going to write...\n";
+    $DEBUG && print "DEBUG: Message->set_data($data)\n";
 
-    if ( not defined $self->{buffer} ) {
-        my $packed = Storable::nfreeze ($data);
-        $self->{buffer} = pack("N", length($packed)).$packed;
-        $self->{length} = length($self->{buffer});
-        $self->{written} = 0;
+    my $packed = Storable::nfreeze ($data);
+
+    if ( length($packed) > $MAX_PACKET_SIZE ) {
+        Event::RPC::Server->instance->log("ERROR: response packet exceeds limit of $MAX_PACKET_SIZE bytes");
+        $data = { rc => 0, msg => "Response packed exceeds limit of $MAX_PACKET_SIZE bytes" };
+        $packed = Storable::nfreeze ($data);
     }
 
+    $self->{buffer} = pack("N", length($packed)).$packed;
+    $self->{length} = length($self->{buffer});
+    $self->{written} = 0;
+
+    1;
+}
+
+sub write {
+    my $self = shift;
+    my ($blocking) = @_;
+
+    $self->get_sock->blocking($blocking?1:0);
+
     my $rc = syswrite (
         $self->get_sock,
         $self->{buffer},
@@ -141,10 +167,10 @@ sub write_blocked {
     my $self = shift;
     my ($data) = @_;
 
-    $self->write($data) and return;
+    $self->set_data($data);
 
     my $finished = 0;
-    $finished = $self->write while not $finished;
+    $finished = $self->write(1) while not $finished;
 
     1;
 }
@@ -153,6 +179,8 @@ sub write_blocked {
 
 __END__
 
+=encoding latin1
+
 =head1 NAME
 
 Event::RPC::Message - Implementation of Event::RPC network protocol
